TransferStatus

Enum TransferStatus 

#[non_exhaustive]
pub enum TransferStatus { Accepted, Progress { status_code: u16, reason: String, }, Completed { status_code: u16, reason: String, }, Failed { status_code: u16, reason: String, }, }
Transport-neutral asynchronous transfer status.

Returning successfully from an adapter’s transfer operation means only that it submitted the transfer request. Protocols such as SIP report authoritative progress and completion later (for example via REFER NOTIFY sipfrags); adapters surface those reports with AdapterEvent::TransferStatus.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Accepted

The remote endpoint accepted responsibility for processing the transfer.



Progress

A provisional status was reported for the transfer target.

Fields

status_code: u16
reason: String


Completed

A final successful status was reported.

Fields

status_code: u16
reason: String


Failed

A final failure status was reported.

Fields

status_code: u16
reason: String